@@ -2,7 +2,7 @@ from functools import wraps
 import json
 
 from pydantic import ValidationError
-from fastapi import FastAPI, Depends, Request, Header
+from fastapi import FastAPI, Depends, Header
 from fastapi.exceptions import HTTPException
 from databases import Database
 
@@ -11,7 +11,6 @@ from fsu.internal.error import FieldNotExist, ObjectNotExist, UnsupportedOperato
 from fsu.internal.schema import ReadMany, ReadOne, UpdateMany, UpdateOne, DeleteMany, DeleteOne, CreateOne, \
                                 LoginIn, LoginOut, GetCurrentUserOut
 import fsu.internal.error_code as E
-from fsu.interceptor import adimap
 from fsu.security import sign_required, jwt_field_required, get_jwt_info
 from fsu.wxwork import get_user_by_code
 from fsu.sql import bind_enhq, verbose_where, find_table
